@@ -25,14 +25,14 @@
 
 #include <powerdevilbackendinterface.h>
 #include <powerdevilcore.h>
+#include <powerdevil_debug.h>
 
 #include <QDesktopWidget>
+#include <QAction>
+#include <QDebug>
 
-#include <KApplication>
-#include <KAction>
 #include <KActionCollection>
 #include <KConfigGroup>
-#include <KDebug>
 #include <KLocalizedString>
 #include <KGlobalAccel>
 namespace PowerDevil {
@@ -40,15 +40,13 @@ namespace BundledActions {
 
 BrightnessControl::BrightnessControl(QObject* parent)
     : Action(parent)
-    , m_brightnessOSD(0)
 {
     // DBus
     new BrightnessControlAdaptor(this);
 
     setRequiredPolicies(PowerDevil::PolicyAgent::ChangeScreenSettings);
 
-    connect(core()->backend(), SIGNAL(brightnessValueChanged(int,int,PowerDevil::BackendInterface::BrightnessControlType)),
-            this, SLOT(onBrightnessChangedFromBackend(int,int,PowerDevil::BackendInterface::BrightnessControlType)));
+    connect(core()->backend(), &PowerDevil::BackendInterface::brightnessChanged, this, &PowerDevil::BundledActions::BrightnessControl::onBrightnessChangedFromBackend);
 
     KGlobalAccel *accel = KGlobalAccel::self();
     KActionCollection* actionCollection = new KActionCollection( this );
@@ -92,7 +90,7 @@ void BrightnessControl::onProfileLoad()
          (m_currentProfile == "LowBattery" && (m_lastProfile == "AC" || m_lastProfile == "Battery"))) &&
         m_defaultValue > brightness()) {
         // We don't want to change anything here
-        kDebug() << "Not changing brightness, the current one is lower and the profile is more conservative";
+        qCDebug(POWERDEVIL) << "Not changing brightness, the current one is lower and the profile is more conservative";
     } else if (m_defaultValue >= 0) {
         QVariantMap args;
         args["Value"] = QVariant::fromValue((float)m_defaultValue);
@@ -102,13 +100,15 @@ void BrightnessControl::onProfileLoad()
 
 void BrightnessControl::triggerImpl(const QVariantMap& args)
 {
-    if ((QMetaType::Type) args["Value"].type() == QMetaType::Int) {
+    if (args.contains("Step")) {
+        backend()->setBrightnessStep(args["Step"].toInt());
+    } else if ((QMetaType::Type) args["Value"].type() == QMetaType::Int) {
         backend()->setBrightnessValue(args["Value"].toInt());
     } else {
         backend()->setBrightness(args["Value"].toFloat());
     }
-    if (args["Explicit"].toBool()) {
-        showBrightnessOSD(backend()->brightness());
+    if (args["Explicit"].toBool() && !args["Silent"].toBool()) {
+        BrightnessOSDWidget::show(brightness());
     }
 }
 
@@ -128,7 +128,7 @@ bool BrightnessControl::loadAction(const KConfigGroup& config)
     m_lastProfile = m_currentProfile;
     m_currentProfile = config.parent().name();
 
-    kDebug() << "Profiles: " << m_currentProfile << m_lastProfile;
+    qCDebug(POWERDEVIL) << "Profiles: " << m_currentProfile << m_lastProfile;
 
     if (config.hasKey("value")) {
         m_defaultValue = config.readEntry<int>("value", 50);
@@ -139,46 +139,48 @@ bool BrightnessControl::loadAction(const KConfigGroup& config)
     return true;
 }
 
-void BrightnessControl::showBrightnessOSD(int brightness)
-{
-    if (!m_brightnessOSD) {
-        m_brightnessOSD = new BrightnessOSDWidget(BackendInterface::Screen, this);
-    }
-
-    m_brightnessOSD->setCurrentBrightness(brightness);
-}
-
-void BrightnessControl::onBrightnessChangedFromBackend(int brightnessValue, int brightnessValueMax, PowerDevil::BackendInterface::BrightnessControlType type)
+void BrightnessControl::onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &info, BackendInterface::BrightnessControlType type)
 {
     if (type == BackendInterface::Screen) {
-        float brightness = (brightnessValueMax > 0) ? brightnessValue * 100.0 / brightnessValueMax : 0.0;
-        Q_EMIT brightnessValueChanged(brightnessValue);
+        int brightness = qRound(info.percentage);
+        Q_EMIT brightnessValueChanged(info.value);
+        Q_EMIT brightnessStepChanged(info.step);
         Q_EMIT brightnessChanged(brightness);
     }
 }
 
 int BrightnessControl::brightness() const
 {
-    return backend()->brightness();
+    return qRound(backend()->brightness());
 }
 
 void BrightnessControl::setBrightness(int percent)
 {
     QVariantMap args;
     args["Value"] = QVariant::fromValue<float>((float)percent);
+    args["Explicit"] = true;
+    trigger(args);
+}
+
+void BrightnessControl::setBrightnessSilent(int percent)
+{
+    QVariantMap args;
+    args["Value"] = QVariant::fromValue<float>((float)percent);
+    args["Explicit"] = true;
+    args["Silent"] = true;
     trigger(args);
 }
 
 void BrightnessControl::increaseBrightness()
 {
-    backend()->brightnessKeyPressed(BackendInterface::Increase);
-    showBrightnessOSD(brightness());
+    backend()->brightnessKeyPressed(BrightnessLogic::Increase);
+    BrightnessOSDWidget::show(brightness());
 }
 
 void BrightnessControl::decreaseBrightness()
 {
-    backend()->brightnessKeyPressed(BackendInterface::Decrease);
-    showBrightnessOSD(brightness());
+    backend()->brightnessKeyPressed(BrightnessLogic::Decrease);
+    BrightnessOSDWidget::show(brightness());
 }
 
 int BrightnessControl::brightnessValue() const
@@ -195,6 +197,34 @@ void BrightnessControl::setBrightnessValue(int value)
 {
     QVariantMap args;
     args["Value"] = QVariant::fromValue<int>(value);
+    args["Explicit"] = true;
+    trigger(args);
+}
+
+void BrightnessControl::setBrightnessValueSilent(int value)
+{
+    QVariantMap args;
+    args["Value"] = QVariant::fromValue<int>(value);
+    args["Explicit"] = true;
+    args["Silent"] = true;
+    trigger(args);
+}
+
+int BrightnessControl::brightnessStep() const
+{
+    return backend()->brightnessStep();
+}
+
+int BrightnessControl::brightnessStepMax() const
+{
+    return backend()->brightnessStepMax();
+}
+
+void BrightnessControl::setBrightnessStep(int step)
+{
+    QVariantMap args;
+    args["Step"] = QVariant::fromValue<int>(step);
+    args["Explicit"] = true;
     trigger(args);
 }
 
