@@ -24,8 +24,6 @@
 #include <powerdevilaction.h>
 #include <powerdevilbackendinterface.h>
 
-class BrightnessOSDWidget;
-
 namespace PowerDevil {
 namespace BundledActions {
 
@@ -51,28 +49,32 @@ public:
     virtual bool loadAction(const KConfigGroup& config);
 
 public Q_SLOTS:
-    void showBrightnessOSD(int brightness);
-
     // DBus export
     void increaseBrightness();
     void decreaseBrightness();
     int brightness() const;
     void setBrightness(int percent);
+    void setBrightnessSilent(int percent);
 
     int brightnessValue() const;
     int brightnessValueMax() const;
     void setBrightnessValue(int value);
+    void setBrightnessValueSilent(int value);
+
+    int brightnessStep() const;
+    int brightnessStepMax() const;
+    void setBrightnessStep(int step);
 
 private Q_SLOTS:
-    void onBrightnessChangedFromBackend(int brightnessValue, int brightnessValueMax, PowerDevil::BackendInterface::BrightnessControlType type);
+    void onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &brightnessInfo, BackendInterface::BrightnessControlType type);
 
 Q_SIGNALS:
     void brightnessChanged(int percent);
     void brightnessValueChanged(int value);
+    void brightnessStepChanged(int step);
 
 private:
     int m_defaultValue;
-    BrightnessOSDWidget *m_brightnessOSD;
     QString m_lastProfile;
     QString m_currentProfile;
 };
