@@ -22,63 +22,30 @@
 
 #include "powerdevilupowerbackend.h"
 
+#include <powerdevil_debug.h>
+
 #include <qtextstream.h>
 #include <QtDBus>
+#include <QDebug>
 
-#include <KDebug>
 #include <kauthexecutejob.h>
 #include <KPluginFactory>
 #include <KSharedConfig>
-#include <KAuth/Action>
+#include <KAuthAction>
 
 #include "xrandrxcbhelper.h"
 #include "xrandrbrightness.h"
 #include "upowersuspendjob.h"
 #include "login1suspendjob.h"
-#include "upstart_interface.h"
 #include "udevqt.h"
 
 #define HELPER_ID "org.kde.powerdevil.backlighthelper"
 
-bool checkSystemdVersion(uint requiredVersion)
-{
-
-    QDBusInterface systemdIface("org.freedesktop.systemd1", "/org/freedesktop/systemd1", "org.freedesktop.systemd1.Manager",
-                                QDBusConnection::systemBus(), 0);
-
-    const QString reply = systemdIface.property("Version").toString();
-
-    QRegExp expsd("(systemd )?([0-9]+)");
-
-    if (expsd.exactMatch(reply)) {
-        const uint version = expsd.cap(2).toUInt();
-        return (version >= requiredVersion);
-    }
-
-    // Since version 1.11 Upstart user sessions implement the exact same API as logind
-    // and are going to the maintain the API in future releases.
-    // Hence, powerdevil can support this init system as well
-    // This has no effect on systemd integration since the check is done after systemd
-    ComUbuntuUpstart0_6Interface upstartInterface(QLatin1String("com.ubuntu.Upstart"),
-                                                  QLatin1String("/com/ubuntu/Upstart"),
-                                                  QDBusConnection::sessionBus());
-
-    QRegExp exp("(?:init \\()?upstart ([0-9.]+)(?:\\))?");
-    if(exp.exactMatch(upstartInterface.version())) {
-        // Only keep the X.Y part of a X.Y.Z version
-        QStringList items = exp.cap(1).split('.').mid(0, 2);
-        const float upstartVersion = items.join(QString('.')).toFloat();
-        return upstartVersion >= 1.1;
-    }
-
-    kDebug() << "No appropriate systemd version or upstart version found";
-    return false;
-}
-
 PowerDevilUPowerBackend::PowerDevilUPowerBackend(QObject* parent)
     : BackendInterface(parent),
       m_brightnessControl(0),
-      m_lidIsPresent(false), m_lidIsClosed(false), m_onBattery(false), m_kbdMaxBrightness(0)
+      m_kbdMaxBrightness(0),
+      m_lidIsPresent(false), m_lidIsClosed(false), m_onBattery(false)
 {
 
 }
@@ -92,7 +59,7 @@ bool PowerDevilUPowerBackend::isAvailable()
 {
     if (!QDBusConnection::systemBus().interface()->isServiceRegistered(UPOWER_SERVICE)) {
         // Is it pending activation?
-        kDebug() << "UPower service, " << UPOWER_SERVICE << ", is not registered on the bus. Trying to find out if it is activated.";
+        qCDebug(POWERDEVIL) << "UPower service, " << UPOWER_SERVICE << ", is not registered on the bus. Trying to find out if it is activated.";
         QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.DBus",
                                                               "/org/freedesktop/DBus",
                                                               "org.freedesktop.DBus",
@@ -103,7 +70,7 @@ bool PowerDevilUPowerBackend::isAvailable()
 
         if (reply.isValid()) {
             if (reply.value().contains(UPOWER_SERVICE)) {
-                kDebug() << "UPower was found, activating service...";
+                qCDebug(POWERDEVIL) << "UPower was found, activating service...";
                 QDBusConnection::systemBus().interface()->startService(UPOWER_SERVICE);
                 if (!QDBusConnection::systemBus().interface()->isServiceRegistered(UPOWER_SERVICE)) {
                     // Wait for it
@@ -122,7 +89,7 @@ bool PowerDevilUPowerBackend::isAvailable()
                         e.exec();
 
                         if (!timer->isActive()) {
-                            kDebug() << "Activation of UPower timed out. There is likely a problem with your configuration.";
+                            qCDebug(POWERDEVIL) << "Activation of UPower timed out. There is likely a problem with your configuration.";
                             timer->deleteLater();
                             return false;
                         }
@@ -132,11 +99,11 @@ bool PowerDevilUPowerBackend::isAvailable()
                 }
                 return true;
             } else {
-                kDebug() << "UPower cannot be found on this system.";
+                qCDebug(POWERDEVIL) << "UPower cannot be found on this system.";
                 return false;
             }
         } else {
-            kWarning() << "Could not request activatable names to DBus!";
+            qCWarning(POWERDEVIL) << "Could not request activatable names to DBus!";
             return false;
         }
     } else {
@@ -165,7 +132,7 @@ void PowerDevilUPowerBackend::init()
     m_upowerInterface = new OrgFreedesktopUPowerInterface(UPOWER_SERVICE, "/org/freedesktop/UPower", QDBusConnection::systemBus(), this);
     m_brightnessControl = new XRandrBrightness();
     if (!m_brightnessControl->isSupported()) {
-        kDebug() << "Using helper";
+        qCDebug(POWERDEVIL) << "Using helper";
         KAuth::Action action("org.kde.powerdevil.backlighthelper.syspath");
         action.setHelperId(HELPER_ID);
         KAuth::ExecuteJob* job = action.execute();
@@ -178,7 +145,7 @@ void PowerDevilUPowerBackend::init()
             screenBrightnessAvailable = true;
         }
     } else {
-        kDebug() << "Using XRandR";
+        qCDebug(POWERDEVIL) << "Using XRandR";
         m_randrHelper = XRandRXCBHelper::self();
         Q_ASSERT(m_randrHelper);
         connect(m_randrHelper, SIGNAL(brightnessChanged()), this, SLOT(slotScreenBrightnessChanged()));
@@ -211,8 +178,8 @@ void PowerDevilUPowerBackend::init()
     BrightnessControlsList controls;
     if (screenBrightnessAvailable) {
         controls.insert(QLatin1String("LVDS1"), Screen);
-        m_cachedBrightnessMap.insert(Screen, brightness(Screen));
-        kDebug() << "current screen brightness: " << m_cachedBrightnessMap.value(Screen);
+        m_cachedBrightnessMap.insert(Screen, brightnessValue(Screen));
+        qCDebug(POWERDEVIL) << "current screen brightness value: " << m_cachedBrightnessMap.value(Screen);
     }
 
     m_kbdBacklight = new OrgFreedesktopUPowerKbdBacklightInterface(UPOWER_SERVICE, "/org/freedesktop/UPower/KbdBacklight", QDBusConnection::systemBus(), this);
@@ -226,15 +193,15 @@ void PowerDevilUPowerBackend::init()
         // TODO Do a proper check if the kbd backlight dbus object exists. But that should work for now ..
         if (m_kbdMaxBrightness) {
             controls.insert(QLatin1String("KBD"), Keyboard);
-            m_cachedBrightnessMap.insert(Keyboard, brightness(Keyboard));
-            kDebug() << "current keyboard backlight brightness: " << m_cachedBrightnessMap.value(Keyboard);
+            m_cachedBrightnessMap.insert(Keyboard, brightnessValue(Keyboard));
+            qCDebug(POWERDEVIL) << "current keyboard backlight brightness value: " << m_cachedBrightnessMap.value(Keyboard);
             connect(m_kbdBacklight, SIGNAL(BrightnessChanged(int)), this, SLOT(onKeyboardBrightnessChanged(int)));
         }
     }
 
     // Supported suspend methods
     SuspendMethods supported = UnknownSuspendMethod;
-    if (m_login1Interface && checkSystemdVersion(195)) {
+    if (m_login1Interface) {
         QDBusPendingReply<QString> canSuspend = m_login1Interface.data()->asyncCall("CanSuspend");
         canSuspend.waitForFinished();
         if (canSuspend.isValid() && (canSuspend.value() == "yes" || canSuspend.value() == "challenge"))
@@ -251,18 +218,18 @@ void PowerDevilUPowerBackend::init()
             supported |= HybridSuspend;
     } else {
         if (m_upowerInterface->canSuspend() && m_upowerInterface->SuspendAllowed()) {
-            kDebug() << "Can suspend";
+            qCDebug(POWERDEVIL) << "Can suspend";
             supported |= ToRam;
         }
 
         if (m_upowerInterface->canHibernate() && m_upowerInterface->HibernateAllowed()) {
-            kDebug() << "Can hibernate";
+            qCDebug(POWERDEVIL) << "Can hibernate";
             supported |= ToDisk;
         }
     }
 
     // "resuming" signal
-    if (m_login1Interface && checkSystemdVersion(198)) {
+    if (m_login1Interface) {
         connect(m_login1Interface.data(), SIGNAL(PrepareForSleep(bool)), this, SLOT(slotLogin1Resuming(bool)));
     } else {
         connect(m_upowerInterface, SIGNAL(Resuming()), this, SIGNAL(resumeFromSuspend()));
@@ -294,7 +261,7 @@ void PowerDevilUPowerBackend::init()
 
 void PowerDevilUPowerBackend::onDeviceChanged(const UdevQt::Device &device)
 {
-    kDebug() << "Udev device changed" << m_syspath << device.sysfsPath();
+    qCDebug(POWERDEVIL) << "Udev device changed" << m_syspath << device.sysfsPath();
     if (device.sysfsPath() != m_syspath) {
         return;
     }
@@ -303,16 +270,15 @@ void PowerDevilUPowerBackend::onDeviceChanged(const UdevQt::Device &device)
     if (maxBrightness <= 0) {
         return;
     }
-    int newBrightnessValue = device.sysfsProperty("brightness").toInt();
-    float newBrightness = newBrightnessValue * 100 / maxBrightness;
+    int newBrightness = device.sysfsProperty("brightness").toInt();
 
-    if (!qFuzzyCompare(newBrightness, m_cachedBrightnessMap[Screen])) {
+    if (newBrightness != m_cachedBrightnessMap[Screen]) {
         m_cachedBrightnessMap[Screen] = newBrightness;
-        onBrightnessChanged(Screen, newBrightnessValue, maxBrightness);
+        onBrightnessChanged(Screen, newBrightness, maxBrightness);
     }
 }
 
-void PowerDevilUPowerBackend::brightnessKeyPressed(PowerDevil::BackendInterface::BrightnessKeyType type, BrightnessControlType controlType)
+void PowerDevilUPowerBackend::brightnessKeyPressed(PowerDevil::BrightnessLogic::BrightnessKeyType type, BrightnessControlType controlType)
 {
     BrightnessControlsList allControls = brightnessControlsAvailable();
     QList<QString> controls = allControls.keys(controlType);
@@ -321,37 +287,20 @@ void PowerDevilUPowerBackend::brightnessKeyPressed(PowerDevil::BackendInterface:
         return; // ignore as we are not able to determine the brightness level
     }
 
-    if (type == Toggle && controlType == Screen) {
-        return; // ignore as we wont toggle the screen off
-    }
-
-    float currentBrightness = brightness(controlType);
-
-    int step = 10;
-    if (controlType == Keyboard) {
-        // In case the keyboard backlight has only 5 or less possible values,
-        // 10% are not enough to hit the next value. Lets use 30% because
-        // that jumps exactly one value for 2, 3, 4 and 5 possible steps
-        // when rounded.
-        if (m_kbdMaxBrightness < 6) {
-            step = 30;
-        }
-    }
-
-    if (qFuzzyCompare(currentBrightness, m_cachedBrightnessMap.value(controlType))) {
-        float newBrightness;
-        if (type == Increase) {
-            newBrightness = qMin(100.0f, currentBrightness + step);
-        } else if (type == Decrease) {
-            newBrightness = qMax(1.0f, currentBrightness - step);
-        } else { // Toggle On/off
-            newBrightness = currentBrightness > 0 ? 0 : 100;
-        }
-
-        setBrightness(newBrightness, controlType);
-    } else {
+    int currentBrightness = brightnessValue(controlType);
+    if (currentBrightness !=  m_cachedBrightnessMap.value(controlType)) {
         m_cachedBrightnessMap[controlType] = currentBrightness;
+        return;
     }
+
+    int maxBrightness = brightnessValueMax(controlType),
+        newBrightness = calculateNextStep(currentBrightness, maxBrightness, controlType, type);
+
+    if (newBrightness < 0) {
+        return;
+    }
+
+    setBrightnessValue(newBrightness, controlType);
 }
 
 int PowerDevilUPowerBackend::brightnessValue(PowerDevil::BackendInterface::BrightnessControlType type) const
@@ -360,25 +309,25 @@ int PowerDevilUPowerBackend::brightnessValue(PowerDevil::BackendInterface::Brigh
 
     if (type == Screen) {
         if (m_brightnessControl->isSupported()) {
-            //kDebug() << "Calling xrandr brightness";
+            //qCDebug(POWERDEVIL) << "Calling xrandr brightness";
             result = (int) m_brightnessControl->brightnessValue();
         } else {
-            //kDebug() << "Falling back to helper to get brightness";
+            //qCDebug(POWERDEVIL) << "Falling back to helper to get brightness";
             KAuth::Action action("org.kde.powerdevil.backlighthelper.brightnessvalue");
             action.setHelperId(HELPER_ID);
             KAuth::ExecuteJob *job = action.execute();
             if (job->exec()) {
                 result = job->data()["brightnessvalue"].toFloat();
-                //kDebug() << "org.kde.powerdevil.backlighthelper.brightnessvalue succeeded: " << reply.data()["brightnessvalue"];
+                //qCDebug(POWERDEVIL) << "org.kde.powerdevil.backlighthelper.brightnessvalue succeeded: " << reply.data()["brightnessvalue"];
             }
             else
-                kWarning() << "org.kde.powerdevil.backlighthelper.brightnessvalue failed";
+                qCWarning(POWERDEVIL) << "org.kde.powerdevil.backlighthelper.brightnessvalue failed";
 
         }
-        kDebug() << "Screen brightness value: " << result;
+        qCDebug(POWERDEVIL) << "Screen brightness value: " << result;
     } else if (type == Keyboard) {
         result = m_kbdBacklight->GetBrightness();
-        kDebug() << "Kbd backlight brightness value: " << result;
+        qCDebug(POWERDEVIL) << "Kbd backlight brightness value: " << result;
     }
 
     return result;
@@ -390,25 +339,25 @@ int PowerDevilUPowerBackend::brightnessValueMax(PowerDevil::BackendInterface::Br
 
     if (type == Screen) {
         if (m_brightnessControl->isSupported()) {
-            //kDebug() << "Calling xrandr brightness";
+            //qCDebug(POWERDEVIL) << "Calling xrandr brightness";
             result = (int) m_brightnessControl->brightnessValueMax();
         } else {
-            //kDebug() << "Falling back to helper to get brightness";
+            //qCDebug(POWERDEVIL) << "Falling back to helper to get brightness";
             KAuth::Action action("org.kde.powerdevil.backlighthelper.brightnessvaluemax");
             action.setHelperId(HELPER_ID);
             KAuth::ExecuteJob *job = action.execute();
             if (job->exec()) {
                 result = job->data()["brightnessvaluemax"].toInt();
-                //kDebug() << "org.kde.powerdevil.backlighthelper.brightnessvaluemax succeeded: " << reply.data()["brightnessvaluemax"];
+                //qCDebug(POWERDEVIL) << "org.kde.powerdevil.backlighthelper.brightnessvaluemax succeeded: " << reply.data()["brightnessvaluemax"];
             }
             else
-                kWarning() << "org.kde.powerdevil.backlighthelper.brightnessvaluemax failed";
+                qCWarning(POWERDEVIL) << "org.kde.powerdevil.backlighthelper.brightnessvaluemax failed";
 
         }
-        kDebug() << "Screen brightness value max: " << result;
+        qCDebug(POWERDEVIL) << "Screen brightness value max: " << result;
     } else if (type == Keyboard) {
         result = m_kbdMaxBrightness;
-        kDebug() << "Kbd backlight brightness value max: " << result;
+        qCDebug(POWERDEVIL) << "Kbd backlight brightness value max: " << result;
     }
 
     return result;
@@ -418,24 +367,24 @@ bool PowerDevilUPowerBackend::setBrightnessValue(int brightnessValue, PowerDevil
 {
     bool success = false;
     if (type == Screen) {
-        kDebug() << "set screen brightness value: " << brightnessValue;
+        qCDebug(POWERDEVIL) << "set screen brightness value: " << brightnessValue;
         if (m_brightnessControl->isSupported()) {
             m_brightnessControl->setBrightnessValue(brightnessValue);
         } else {
-            //kDebug() << "Falling back to helper to set brightness";
+            //qCDebug(POWERDEVIL) << "Falling back to helper to set brightness";
             KAuth::Action action("org.kde.powerdevil.backlighthelper.setbrightnessvalue");
             action.setHelperId(HELPER_ID);
             action.addArgument("brightnessvalue", brightnessValue);
             KAuth::ExecuteJob *job = action.execute();
             if (!job->exec()) {
-                kWarning() << "org.kde.powerdevil.backlighthelper.setbrightnessvalue failed";
+                qCWarning(POWERDEVIL) << "org.kde.powerdevil.backlighthelper.setbrightnessvalue failed";
                 return false;
             }
         }
 
         success = true;
     } else if (type == Keyboard) {
-        kDebug() << "set kbd backlight value: " << brightnessValue;
+        qCDebug(POWERDEVIL) << "set kbd backlight value: " << brightnessValue;
         m_kbdBacklight->SetBrightness(brightnessValue);
         success = true;
     }
@@ -445,27 +394,26 @@ bool PowerDevilUPowerBackend::setBrightnessValue(int brightnessValue, PowerDevil
 
 void PowerDevilUPowerBackend::slotScreenBrightnessChanged()
 {
-    float newBrightness = brightness(Screen);
-    kDebug() << "Brightness changed!!";
-    if (!qFuzzyCompare(newBrightness, m_cachedBrightnessMap[Screen])) {
-        m_cachedBrightnessMap[Screen] = newBrightness;
-        onBrightnessChanged(Screen, brightnessValue(Screen), brightnessValueMax(Screen));
+    int value = brightnessValue(Screen);
+    qCDebug(POWERDEVIL) << "Brightness changed!!";
+    if (value != m_cachedBrightnessMap[Screen]) {
+        m_cachedBrightnessMap[Screen] = value;
+        onBrightnessChanged(Screen, value, brightnessValueMax(Screen));
     }
 }
 
 void PowerDevilUPowerBackend::onKeyboardBrightnessChanged(int value)
 {
-    kDebug() << "Keyboard brightness changed!!";
-    float realValue = 1.0 * value / m_kbdMaxBrightness * 100;
-    if (!qFuzzyCompare(realValue, m_cachedBrightnessMap[Keyboard])) {
-        m_cachedBrightnessMap[Keyboard] = realValue;
-        onBrightnessChanged(Keyboard, value, m_kbdMaxBrightness);
+    qCDebug(POWERDEVIL) << "Keyboard brightness changed!!";
+    if (value != m_cachedBrightnessMap[Keyboard]) {
+        m_cachedBrightnessMap[Keyboard] = value;
+        onBrightnessChanged(Keyboard, value, brightnessValueMax(Keyboard));
     }
 }
 
 KJob* PowerDevilUPowerBackend::suspend(PowerDevil::BackendInterface::SuspendMethod method)
 {
-    if (m_login1Interface && checkSystemdVersion(195)) {
+    if (m_login1Interface) {
         return new Login1SuspendJob(m_login1Interface.data(), method, supportedSuspendMethods());
     } else {
         return new UPowerSuspendJob(m_upowerInterface, method, supportedSuspendMethods());
